cdm_is_referenced: Is a table of a dm referenced by another table?
Description
Is a table of a dm referenced by another table?
Usage
cdm_is_referenced(dm, table)
Value
TRUE if at least one foreign key exists that points to the primary
key of the table argument, FALSE otherwise.