dm to anotherCan either remove one reference between the two tables or all at once if parameter column = NULL.
All parameters can be provided unquoted or quoted.
cdm_rm_fk(dm, table, column, ref_table)A dm object.
A table in the dm
The column of table which should no longer be referencing the primary
key of ref_table.
If NULL, all columns will be considered.
The table which table was referencing.
Other foreign key functions:
cdm_add_fk(),
cdm_enum_fk_candidates(),
cdm_get_all_fks(),
cdm_get_fk(),
cdm_has_fk()