dm table to anotherThis function can remove either one reference between two tables, or all references at once, if argument column = NULL.
All arguments may be provided quoted or unquoted.
dm_rm_fk(dm, table, column, ref_table)A dm object.
A table in the dm.
The column of table that should no longer be referencing the primary key of ref_table.
If NULL, all columns will be evaluated.
The table that table was referencing.
Other foreign key functions:
dm_add_fk(),
dm_enum_fk_candidates(),
dm_get_all_fks(),
dm_get_fk(),
dm_has_fk()