| tidyr_table_manipulation | R Documentation |
Use these methods without the '.dm_zoomed' suffix (see examples).
## S3 method for class 'dm_zoomed'
unite(data, col, ..., sep = "_", remove = TRUE, na.rm = FALSE)
## S3 method for class 'dm_keyed_tbl'
unite(data, col, ..., sep = "_", remove = TRUE, na.rm = FALSE)
## S3 method for class 'dm_zoomed'
separate(
data,
col,
into,
sep = "[^[:alnum:]]+",
remove = TRUE,
convert = FALSE,
extra = "warn",
fill = "warn",
...
)
## S3 method for class 'dm_keyed_tbl'
separate(
data,
col,
into,
sep = "[^[:alnum:]]+",
remove = TRUE,
convert = FALSE,
extra = "warn",
fill = "warn",
...
)
data |
object of class |
col |
The name of the new column, as a string or symbol. This argument is passed by expression and supports
quasiquotation (you can unquote strings
and symbols). The name is captured from the expression with
|
... |
For For |
sep |
Separator to use between values. |
remove |
If |
na.rm |
If |
into |
Names of new variables to create as character vector.
Use |
convert |
If NB: this will cause string |
extra |
If
|
fill |
If
|
zoom_united <- dm_nycflights13() %>%
dm_zoom_to(flights) %>%
select(year, month, day) %>%
unite("month_day", month, day)
zoom_united
zoom_united %>%
separate(month_day, c("month", "day"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.