cdm_disambiguate_cols: Avoid conflicts in column names
Description
This function checks all tables for column names that are not unique (across the entire dm object), and renames
those columns by prefixing the respective table name and a separator.
Key columns will not be renamed because only one column should remain when two tables that are
linked by a key relation are joined.