| dm_draw | R Documentation |
dm_draw() draws a diagram, a visual representation of the data model.
dm_draw(
dm,
rankdir = "LR",
...,
col_attr = NULL,
view_type = c("keys_only", "all", "title_only"),
column_types = NULL,
backend = c("DiagrammeR"),
backend_opts = list(),
columnArrows = lifecycle::deprecated(),
graph_attrs = lifecycle::deprecated(),
node_attrs = lifecycle::deprecated(),
edge_attrs = lifecycle::deprecated(),
focus = lifecycle::deprecated(),
graph_name = lifecycle::deprecated(),
font_size = lifecycle::deprecated()
)
Currently, dm uses DiagrammeR to draw diagrams.
Use DiagrammeRsvg::export_svg() to convert the diagram to an SVG file.
The backend for drawing the diagrams might change in the future.
If you rely on DiagrammeR, pass an explicit value for the backend argument.
An object with a print() method, which,
when printed, produces the output seen in the viewer as a side effect.
Currently, this is an object of class grViz (see also
DiagrammeR::grViz()), but this is subject to change.
dm_set_colors() for defining the table colors.
dm_set_table_description() for adding details to one or more tables in the diagram
dm_nycflights13() %>%
dm_draw()
dm_nycflights13(cycle = TRUE) %>%
dm_draw(view_type = "title_only")
head(dm_get_available_colors())
length(dm_get_available_colors())
dm_nycflights13() %>%
dm_get_colors()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.