| dm_flatten | R Documentation |
dm by joining its parent tablesdm_flatten() updates a table in-place by joining its parent tables into it,
and removes the now integrated parent tables from the dm.
dm_flatten(
dm,
table,
...,
parent_tables = NULL,
recursive = FALSE,
allow_deep = FALSE,
join = left_join
)
dm |
A |
table |
The table to flatten by joining its parent tables. An interesting choice could be for example a fact table in a star schema. |
... |
These dots are for future extensions and must be empty. |
parent_tables |
Unquoted names of the parent tables to be joined into |
recursive |
Logical, defaults to |
allow_deep |
Logical, defaults to |
join |
The type of join to use when combining parent tables,
see |
A dm object with the flattened table and removed parent tables.
Other flattening functions:
dm_flatten_to_tbl()
dm_nycflights13() %>%
dm_select_tbl(-weather) %>%
dm_flatten(flights, recursive = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.