| dplyr_join | R Documentation |
Use these methods without the '.dm_zoomed' suffix (see examples).
## S3 method for class 'dm_zoomed'
left_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL,
select = NULL
)
## S3 method for class 'dm_keyed_tbl'
left_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = FALSE,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL
)
## S3 method for class 'dm_zoomed'
inner_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL,
select = NULL
)
## S3 method for class 'dm_keyed_tbl'
inner_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = FALSE,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL
)
## S3 method for class 'dm_zoomed'
full_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
relationship = NULL,
select = NULL
)
## S3 method for class 'dm_keyed_tbl'
full_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = FALSE,
na_matches = c("na", "never"),
multiple = "all",
relationship = NULL
)
## S3 method for class 'dm_zoomed'
right_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = NULL,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL,
select = NULL
)
## S3 method for class 'dm_keyed_tbl'
right_join(
x,
y,
by = NULL,
copy = NULL,
suffix = NULL,
...,
keep = FALSE,
na_matches = c("na", "never"),
multiple = "all",
unmatched = "drop",
relationship = NULL
)
## S3 method for class 'dm_zoomed'
semi_join(
x,
y,
by = NULL,
copy = NULL,
...,
na_matches = c("na", "never"),
suffix = NULL,
select = NULL
)
## S3 method for class 'dm_keyed_tbl'
semi_join(x, y, by = NULL, copy = NULL, ..., na_matches = c("na", "never"))
## S3 method for class 'dm_zoomed'
anti_join(
x,
y,
by = NULL,
copy = NULL,
...,
na_matches = c("na", "never"),
suffix = NULL,
select = NULL
)
## S3 method for class 'dm_keyed_tbl'
anti_join(x, y, by = NULL, copy = NULL, ..., na_matches = c("na", "never"))
## S3 method for class 'dm_zoomed'
nest_join(
x,
y,
by = NULL,
copy = FALSE,
keep = NULL,
name = NULL,
...,
na_matches = c("na", "never"),
unmatched = "drop"
)
## S3 method for class 'dm_zoomed'
cross_join(x, y, ..., copy = NULL, suffix = c(".x", ".y"))
## S3 method for class 'dm_keyed_tbl'
cross_join(x, y, ..., copy = NULL, suffix = c(".x", ".y"))
x, y |
tbls to join. |
by |
If left |
copy |
Disabled, since all tables in a |
suffix |
Disabled, since columns are disambiguated automatically if necessary, changing the column names to |
... |
see |
keep |
Should the join keys from both
|
na_matches |
Should two
|
multiple |
Handling of rows in
|
unmatched |
How should unmatched keys that would result in dropped rows be handled?
|
relationship |
Handling of the expected relationship between the keys of
|
select |
Select a subset of the RHS-table's columns, the syntax being |
name |
The name of the list-column created by the join. If |
flights_dm <- dm_nycflights13()
dm_zoom_to(flights_dm, flights) %>%
left_join(airports, select = c(faa, name))
# this should illustrate that tables don't necessarily need to be connected
dm_zoom_to(flights_dm, airports) %>%
semi_join(airlines, by = "name")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.