Perform table fusion by combining two tables by a common (key) column, and then removing this column.
reunite_parent_child(): After joining the two tables by the column id_column, this column will be removed.
The transformation is roughly the
inverse of what decompose_table() does.
reunite_parent_child_from_list(): After joining the two tables
by the column id_column, id_column is removed.
This function is almost exactly the inverse of decompose_table() (the order
of the columns is not retained, and the original row names are lost).
reunite_parent_child(child_table, parent_table, id_column)reunite_parent_child_from_list(list_of_parent_child_tables, id_column)
Table (possibly created by decompose_table()) that references parent_table
Table (possibly created by decompose_table()).
Identical name of referencing / referenced column in child_table/parent_table.
Cf arguments child_table and parent_table from
reunite_parent_child(), but both in a named list (as created by decompose_table()).
Other table surgery functions:
decompose_table()
Other table surgery functions:
decompose_table()